@@ -17,11 +17,11 @@ areas_to_points:    (dict) Dictionary with the cluster id as keys and a list of
 
 """
 
-def GMM_Clustering(features_X, features_position, n_components = 2, tol=1e-3, reg_covar=1e-6):
+def GMM_Clustering(features_X, features_position, n_clusters = 2, covariance_type = "full", tol=1e-3, reg_covar=1e-6):
     features_X = data_format(features_X)
     features_position = position_data_format(features_position)
     points = list(zip(features_position.lon, features_position.lat))
-    gmm = GaussianMixture(n_components=n_components, tol=tol, reg_covar=reg_covar).fit(features_X)
+    gmm = GaussianMixture(n_components=n_clusters, covariance_type=covariance_type, tol=tol, reg_covar=reg_covar).fit(features_X)
     clusters = gmm.predict(features_X)
 
     areas_to_points = get_areas(clusters, points)
